@@ -32,7 +32,7 @@ sub new {
     $self->{'state_colors'}[$_]   = color( $default_color_def ) for $self->{'state_count'} .. $self->{'last_state'};
     $self->{'state_marker'}       = [ map { App::GUI::Cellgraph::Widget::PositionMarker->new($self, $self->{'rule_square_size'}, 20, $_, '', $default_color_def) } 0 ..$self->{'last_state'} ];
     $self->{'state_pic'}[$_]      = App::GUI::Cellgraph::Widget::ColorDisplay->new
-        ($self, $self->{'rule_square_size'}, $self->{'rule_square_size'},
+        ($self, $self->{'rule_square_size'}, $self->{'rule_square_size'}-5,
          $_, $self->{'state_colors'}[$_]->values(as => 'hash')          ) for 0 .. $self->{'last_state'};
     $self->{'color_set_store_lbl'}= Wx::StaticText->new($self, -1, 'Color Set Store' );
     $self->{'color_set_f_lbl'}    = Wx::StaticText->new($self, -1, 'Colors Set Function' );
